
# Slot: employed at




URI: [ks:employed_at](https://w3id.org/linkml/tests/kitchen_sink/employed_at)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Company](Company.md)

## Parents


## Children


## Used by

 * [EmploymentEvent](EmploymentEvent.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | subset A |

